pub unsafe extern "C" fn kure_context_get_error(
self_: *mut KureContext,
) -> *mut KureErrorExpand description
\return The current error object which may be NULL.
pub unsafe extern "C" fn kure_context_get_error(
self_: *mut KureContext,
) -> *mut KureError\return The current error object which may be NULL.