kure_lang_set_assert_func

Function kure_lang_set_assert_func 

pub unsafe extern "C" fn kure_lang_set_assert_func(
    L: *mut lua_State,
    arg1: Option<unsafe extern "C" fn(arg1: *mut lua_State) -> c_int>,
)
Sets the current callback function which is called if an assertion fails. The function is directly called from within Lua and has to take the assertions name as first argument.