pub unsafe extern "C" fn kure_lua_new(
context: *mut KureContext,
) -> *mut lua_StateExpand description
Creates a new \ref lua_State which can be used with the Kure-Lua binding and the embedded language afterwards. The returned \ref lua_State has the following properties:
- luaL_openlibs was called.
- The given context is used to set the global Lua variable ‘__c’. This variable has a special measing for the embedded language and should not be changed! The \ref lua_State can’t be used after the given \ref KureContext was destroyed. The \ref lua_State holds a reference of the context (see kure_context_ref).
- The Kure library binding is added. (kure.*)
- Some compatibilty functions are loaded which are used internally with the embedded language. (kure.compat.*)
\see kure_lua_destroy, kua_lua_exec, kure_lang_exec, kure_lua_load, kure_lua_load_file