kure_lua_set_global_context

Function kure_lua_set_global_context 

pub unsafe extern "C" fn kure_lua_set_global_context(
    L: *mut lua_State,
    c: *mut KureContext,
)
Sets the current global \ref KureContext. The context is used in operations where no context is passed explicitly and where it cannot derived from operands. This is mainly the case in the domain-specific embedded language.