kure_set_error

Function kure_set_error 

pub unsafe extern "C" fn kure_set_error(
    perr: *mut *mut KureError,
    code: KureErrorCode,
    fmt: *const c_char,
    ...
)
Sets an error if perr is non-NULL. Does nothing otherwise. A \ref gmp_printf compatible operation is used to create the message. The fmt argument may be NULL. In this case the message would be set to “Unknown”.